Manager

Struct Manager 

pub struct Manager { /* private fields */ }
Manager is used to hold active allocations.

Implementations

Source

impl Manager

pub fn new(config: ManagerConfig) -> Self

Creates a new Manager.

pub async fn close(&self) -> Result<(), Error>

Closes this [manager] and closes all Allocations it manages.

pub async fn get_allocations_info( &self, five_tuples: Option<Vec<FiveTuple>>, ) -> HashMap<FiveTuple, AllocationInfo>

Returns the information about the all Allocations associated with the specified FiveTuples.

pub async fn get_allocation( &self, five_tuple: &FiveTuple, ) -> Option<Arc<Allocation>>

Fetches the Allocation matching the passed FiveTuple.

pub async fn create_allocation( &self, five_tuple: FiveTuple, turn_socket: Arc<dyn Conn + Send + Sync>, requested_port: u16, lifetime: Duration, username: Username, use_ipv4: bool, ) -> Result<Arc<Allocation>, Error>

Creates a new Allocation and starts relaying.

pub async fn delete_allocation(&self, five_tuple: &FiveTuple)

Removes an Allocation.

pub async fn delete_allocations_by_username(&self, name: &str)

Deletes the Allocations according to the specified username name.

pub async fn create_reservation(&self, reservation_token: String, port: u16)

Stores the reservation for the token+port.

pub async fn get_reservation(&self, reservation_token: &str) -> Option<u16>

Returns the port for a given reservation if it exists.

pub async fn get_random_even_port(&self) -> Result<u16, Error>

Returns a random un-allocated udp4 port.