Server

Struct Server 

pub struct Server { /* private fields */ }
Server is an instance of the TURN Server

Implementations

Source

impl Server

pub async fn new(config: ServerConfig) -> Result<Self, Error>

creates a new TURN server

pub async fn delete_allocations_by_username( &self, username: String, ) -> Result<(), Error>

Deletes all existing Allocations by the provided username.

pub async fn get_allocations_info( &self, five_tuples: Option<Vec<FiveTuple>>, ) -> Result<HashMap<FiveTuple, AllocationInfo>, Error>

Get information of Allocations by specified FiveTuples.

If five_tuples is:

  • None: It returns information about the all Allocations.
  • Some and not empty: It returns information about the Allocations associated with the specified [FiveTuples].
  • Some, but empty: It returns an empty HashMap.
pub async fn close(&self) -> Result<(), Error>

Close stops the TURN Server. It cleans up any associated state and closes all connections it is managing.