pub struct ServerConfig {
pub conn_configs: Vec<ConnConfig>,
pub realm: String,
pub auth_handler: Arc<dyn AuthHandler + Send + Sync>,
pub channel_bind_timeout: Duration,
pub alloc_close_notify: Option<Sender<AllocationInfo>>,
}Expand description
ServerConfig configures the TURN Server
Fields
conn_configs: Vec<ConnConfig>conn_configs are a list of all the turn listeners.
Each listener can have custom behavior around the creation of Relays.
realm: Stringrealm sets the realm for this server
auth_handler: Arc<dyn AuthHandler + Send + Sync>auth_handler is a callback used to handle incoming auth requests,
allowing users to customize Pion TURN with custom behavior.
channel_bind_timeout: Durationchannel_bind_timeout sets the lifetime of channel binding. Defaults to 10 minutes.
alloc_close_notify: Option<Sender<AllocationInfo>>To receive notify on allocation close event, with metrics data.
Implementations